/**
 * The window object represents the window itself. The document property of a window points to the DOM document loaded in that window. A window for a given document can be obtained using the document.defaultView property.
 */
var window = new Window();
/**
 * Returns a reference to the window that opened this current window.
 * @returns {Window} 
 * @static
 */
window.opener;

/**
 * An event handler property for pageshow events on the window.
 * @returns {Function} 
 * @static
 */
window.onpageshow;

/**
 * Returns the personalbar object, whose visibility can be toggled in the window.
 * @returns {Object} 
 * @static
 */
window.personalbar;

/**
 * Used for creating an object representing an HTML option. Implements HTMLOptionElement.
 * @syntax option = new window.Option(text, value, defaultSelected, selected)
 * @param {String} text the displayed text for the option
 * @param {String} value the form value
 * @param {Boolean} defaultSelected a boolean which does not actually select the option, but is used to indicate the state of the defaultSelected property (of relevance for any future checks to check whether the option is meant to be selected by default)
 * @param {Boolean} selected a boolean to indicate whether the option will be "selected"; if omitted, it will not be selected
 * @returns {HTMLOptionElement} 
 * @static
 */
window.Option = function(text, value, defaultSelected, selected) {};

/**
 * This method is used to break-up long running operations and run a callback function immediately after the browser has completed other operations such as events and display updates. 
 * @syntax var immediateID = setImmediate(func, [param1, param2, ...]);<br>var immediateID = setImmediate(func);
 * @param {Function} func func is the function you wish to call
 * @param {Object} param1,param2,... All parameters will be passed directly to your function.
 * @returns {immediateID} immediateID is the ID of the immediate which can be used later with window.clearImmediate
 * @static
 */
window.setImmediate = function(func, ) {};

/**
 * Returns the maximum number of pixels that the document can be scrolled horizontally.
 * @returns {Number} 
 * @static
 */
window.scrollMaxX;

/**
 * Returns the maximum number of pixels that the document can be scrolled vertically.
 * @returns {Number} 
 * @static
 */
window.scrollMaxY;

/**
 * This property indicates whether the window is displayed in full screen mode or not. It is only reliable in Gecko 1.9 (Firefox 3) and later, see the Notes below. 
 * @returns {Boolean} 
 * @static
 */
window.fullScreen;

/**
 * The crypto API allows web pages access to certain cryptographic related services. These services are a balance between the functionality web pages need, and the requirement to protect users from malicious web sites.
 * @returns {crypto} 
 * @static
 */
window.crypto;

/**
 * Creates a new secondary browser window and loads the referenced resource.
 * @syntax var windowObjectReference = window.open(strUrl, strWindowName[, strWindowFeatures]);
 * @param {String} strUrl The URL to be loaded in the newly opened window.  strUrl can be an HTML document on the web, image file or any resource supported by the browser.
 * @param {String} strWindowName A string name for the new window. The name can be used as the target of links and forms using the target attribute of an <a> or <form> element. The name should not contain any blank space. Note that strWindowName does not specify the title of the new window.
 * @param {String} strWindowFeatures Optional parameter listing the features (size, position, scrollbars, etc.) of the new window. The string must not contain any blank space, each feature name and value must be separated by a comma.
 * @returns {Window} A reference to the newly created window. If the call failed, it will be null. The reference can be used to access properties and methods of the new window provided it complies with Same origin policy security requirements.
 * @static
 */
window.open = function(strUrl, strWindowName) {};

/**
 * Moves the window one document forward in the history. 
 * @syntax window.forward()
 * @returns {undefined} 
 * @static
 */
window.forward = function() {};

/**
 * An event handler property for popstate events, which are fired when navigating to a session history entry representing a state object.
 * @returns {Function} 
 * @static
 */
window.onpopstate;

/**
 * An event handler property for paint events on the window.
 * @returns {Function} 
 * @static
 */
window.onpaint;

/**
 * localStorage is the same as sessionStorage with same same-origin rules applied but it is persistent.
 * @returns {Storage} 
 * @static
 */
window.localStorage;

/**
 * Makes a request to bring the window to the front. It may fail due to user settings and the window isn't guaranteed to be frontmost before this method returns.
 * @syntax window.focus()
 * @returns {undefined} 
 * @static
 */
window.focus = function() {};

/**
 * Scrolls the current document by the specified number of pages. 
 * @syntax window.scrollByPages(pages)
 * @param {Number} pages Pages is the number of pages to scroll. Pages may be a positive or negative integer.
 * @returns {undefined} 
 * @static
 */
window.scrollByPages = function(pages) {};

/**
 * Returns the number of pixels that the document has already been scrolled horizontally.
 * @returns {Number} 
 * @static
 */
window.pageXOffset;

/**
 * An event handler property for before-unload events on the window.
 * @returns {Function} 
 * @static
 */
window.onbeforeunload;

/**
 * Returns a reference to the screen object associated with the window.
 * @returns {screen} 
 * @static
 */
window.screen;

/**
 * Display an alert dialog with the specified content and an OK button.
 * @param {String} message message is a string of text you want to display in the alert dialog, or, alternatively, an object that is converted into a string and displayed.
 * @returns {undefined} 
 * @static
 */
window.alert = function() {};

/**
 * Creates a base-64 encoded ASCII string from a string of binary data. Please note that this is not suitable for raw Unicode strings! See Unicode section below.
 * @syntax var encodedData = window.btoa(stringToEncode);
 * @param {String} stringToEncode 
 * @returns {undefined} 
 * @static
 */
window.btoa = function(stringToEncode) {};

/**
 * The entry point to many XPCOM features. Some properties, e.g. classes, are only available to sufficiently privileged code.
 * @returns {Components} 
 * @static
 */
window.Components;

/**
 * Returns a reference to the window object of the sidebar.
 * @returns {Object} 
 * @static
 */
window.sidebar;

/**
 * This method clears the action specified by window.setImmediate .
 * @syntax window.clearImmediate(immediateID)
 * @param {Number} immediateID immediateID is a ID returned by window.setImmediate .
 * @returns {undefined} 
 * @static
 */
window.clearImmediate = function(immediateID) {};

/**
 * window.outerWidth gets the width of the outside of the browser window. It represents the width of the whole browser window including sidebar (if expanded), window chrome and window resizing borders/handles.
 * @returns {Number} 
 * @static
 */
window.outerWidth;

/**
 * Returns a Window object for the primary content window. This is useful in XUL windows that have a <browser> (or tabbrowser or <iframe>) with type="content-primary" attribute on it - the most famous example is Firefox main window, browser.xul. In such cases, content returns a reference to the Window object for the document currently displayed in the browser. It is a shortcut for browserRef.contentWindow. In unprivileged content (webpages), content is normally equivalent to top (except in the case of a webpage loaded in a sidebar, content still refers to the Window of the currently selected tab).
 * @returns {Window} 
 * @static
 */
window.content;

/**
 * Returns the window itself, which is an array-like object, listing the direct sub-frames of the current window.
 * @returns {Array} 
 * @static
 */
window.frames;

/**
 * Width (in pixels) of the browser window viewport including, if rendered, the vertical scrollbar.
 * @returns {Number} 
 * @static
 */
window.innerWidth;

/**
 * An event handler property for mousedown events on the window.
 * @returns {Function} 
 * @static
 */
window.onmousedown;

/**
 * Returns the number of pixels that the document has already been scrolled horizontally.
 * @returns {Number} 
 * @static
 */
window.pageYOffset;

/**
 * addEventListener() registers a single event listener on a single target. The event target may be a single element in a document, the document itself, a window, or an XMLHttpRequest. To register more than one event listener for the target, call addEventListener() for the same target but with different event types or capture parameters.
 * @syntax target.addEventListener(type, listener[, useCapture])
 * @param {String} type A string representing the event type to listen for.
 * @param {Function} listener The object that receives a notification when an event of the specified type occurs. This must be an object implementing the EventListener interface, or simply a JavaScript function.
 * @param {Boolean} useCapture If true, useCapture indicates that the user wishes to initiate capture. After initiating capture, all events of the specified type will be dispatched to the registered listener before being dispatched to any EventTarget beneath it in the DOM tree. Events which are bubbling upward through the tree will not trigger a listener designated to use capture. See DOM Level 3 Events for a detailed explanation. Note that this parameter is not optional in all browser versions. If not specified, useCapture is false.
 * @param {Boolean} aWantsUntrusted If true, the event can be triggered by untrusted content. See Interaction between privileged and non-privileged pages.
 * @returns {undefined} 
 * @static
 */
window.addEventListener = function(type, listener) {};

/**
 * An event handler property for unload events on the window.
 * @returns {Function} 
 * @static
 */
window.onunload;

/**
 * removeEventListener() allows the removal of event listeners from the event target
 * @syntax element.removeEventListener(type, listener, useCapture)
 * @param {String} type A string representing the event type being removed.
 * @param {Function} listener The listener parameter indicates the EventListener function to be removed.
 * @param {Boolean} useCapture Specifies whether the EventListener being removed was registered as a capturing listener or not. If a listener was registered twice, one with capture and one without, each must be removed separately. Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.
 * @returns {undefined} 
 * @static
 */
window.removeEventListener = function(type, listener, useCapture) {};

/**
 * Returns the number of pixels that the document has already been scrolled horizontally.
 * @returns {Number} 
 * @static
 */
window.scrollY;

/**
 * Returns the number of pixels that the document has already been scrolled horizontally.
 * @returns {Number} 
 * @static
 */
window.scrollX;

/**
 * Encodes a string, replacing certain characters with a hexadecimal escape sequence.
 * @syntax escaped = escape(regular);
 * @param {String} message escaped is the encoded string.
 * @returns {String} 
 * @static
 */
window.escape = function(regular) {};

/**
 * Returns a reference to the document contained in the window.
 * @returns {document} 
 * @static
 */
window.document;

/**
 * Used for creating an object representing an HTML img. Implements HTMLImageElement. The constructor accepts two optional parameters: width and height.
 * @syntax image = new window.Image(width, height)
 * @param {Number} width null
 * @param {Number} height null
 * @returns {HTMLImageElement} 
 * @static
 */
window.Image = function(width, height) {};

/**
 * Returns the number of frames (either frame or iframe elements) in the window. 
 * @returns {Number} 
 * @static
 */
window.length;

/**
 * An event handler property for pagehide events on the window.
 * @returns {Function} 
 * @static
 */
window.onpagehide;

/**
 * Creates and displays a modal dialog box containing a specified HTML document.
 * @syntax returnVal = window.showModalDialog(uri[, arguments][, options]);
 * @param {String} url uri is the URI of the document to display in the dialog box
 * @param {String} arguments arguments is an optional variant that contains values that should be passed to the dialog box; these are made available in the window object's window.dialogArguments property
 * @param {String} options options an optional string that specifies window ornamentation for the dialog box, using one or more semicolon delimited values
 * @returns {Number} returnVal is a variant, indicating the returnValue property as set by the window of the document specified by uri
 * @static
 */
window.showModalDialog = function(uri) {};

/**
 * This property indicates whether the referenced window is closed or not. 
 * @returns {Boolean} 
 * @static
 */
window.closed;

/**
 * An event handler property for handling the window close event.
 * @returns {Function} 
 * @static
 */
window.onclose;

/**
 * Changes the cursor for the current window.
 * @syntax window.setCursor()
 * @returns {undefined} 
 * @static
 */
window.setCursor = function() {};

/**
 * window.outerHeight gets the height in pixels of the whole browser window. It represents the height of the whole browser window including sidebar (if expanded), window chrome and window resizing borders/handles.
 * @returns {Number} 
 * @static
 */
window.outerHeight;

/**
 * Returns the window to the previous item in the history. 
 * @syntax window.back()
 * @returns {undefined} 
 * @static
 */
window.back = function() {};

/**
 * An event handler property for keydown events on the window.
 * @returns {Function} 
 * @static
 */
window.onkeydown;

/**
 * An event handler property for keypress events on the window.
 * @returns {Function} 
 * @static
 */
window.onkeypress;

/**
 * Height (in pixels) of the browser window viewport including, if rendered, the horizontal scrollbar.
 * @returns {Number} 
 * @static
 */
window.innerHeight;

/**
 * An event handler property for submits on window forms.
 * @returns {Function} 
 * @static
 */
window.onsubmit;

/**
 * Attempts to get the user's attention. How this happens varies based on OS and window manager. 
 * @syntax window.getAttention()
 * @returns {undefined} 
 * @static
 */
window.getAttention = function() {};

/**
 * Returns a reference to the History object, which provides an interface for manipulating the browser session history (pages visited in the tab or frame that the current page is loaded in).
 * @returns {History} 
 * @static
 */
window.history;

/**
 * Returns the XUL controllers of the chrome window.
 * @returns {XULControllers} 
 * @static
 */
window.controllers;

/**
 * Executes a code snippet or a function after specified delay.
 * @syntax var timeoutID = window.setTimeout(func, delay, [param1, param2, ...]);<br>var timeoutID = window.setTimeout(code, delay);
 * @param {Function} func func is the function you want to execute after delay milliseconds
 * @param {String} code code in the alternate syntax, is a string of code you want to execute after delay milliseconds. (Using this syntax is not_recommended for the same reasons as using eval())
 * @param {Number} delay delay is the number of milliseconds (thousandths of a second) that the function call should be delayed by. The actual delay may be longer, see Notes below
 * @param {Object} param1,param2,... All parameters will be passed directly to your function.
 * @returns {Number} timeoutID is the numerical ID of the timeout, which can be used later with window.clearTimeout
 * @static
 */
window.setTimeout = function(func, delay, ) {};

/**
 * An event handler property for window scrolling.
 * @returns {Function} 
 * @static
 */
window.onscroll;

/**
 * Returns a selection object representing the range of text selected by the user. 
 * @syntax selection = window.getSelection() ;
 * @returns {Selection} 
 * @static
 */
window.getSelection = function() {};

/**
 * An event handler property for drag and drop events on the window.
 * @returns {Function} 
 * @static
 */
window.ondragdrop;

/**
 * Displays a dialog with a message prompting the user to input some text.
 * @syntax result = window.prompt(text, value);
 * @param {String} text text is a string of text to display to the user. This parameter are optional and can be omitted if there is nothing to show in the prompt window.
 * @param {String} value value is a string containing the default value displayed in the text input field. It is an optional parameter. Note that in Internet Explorer 7 and 8, if you do not provide this parameter, the string "undefined" is the default value.
 * @returns {String|null} result is a string containing the text entered by the user, or the value null
 * @static
 */
window.prompt = function(text, value) {};

/**
 * Displays a modal dialog with a message and two buttons, OK and Cancel.
 * @syntax result = window.confirm(message);
 * @param {String} message message is the string to be displayed in the dialog. 
 * @returns {Boolean} 
 * @static
 */
window.confirm = function(message) {};

/**
 * window.openDialog is an extension to window.open. It behaves the same, except that it can optionally take one or more parameters past windowFeatures, and windowFeatures itself is treated a little differently. <br>The optional parameters, if present, will be bundled up in a JavaScript Array object and added to the newly created window as a property named window.arguments. They may be referenced in the JavaScript of the window at any time, including during the execution of a load handler. These parameters may be used, then, to pass arguments to and from the dialog window. Note that the call to openDialog() returns immediately. If you want the call to block until the user has closed the dialog, supply modal as a windowFeatures parameter. Note that this also means the user won't be able to interact with the opener window until he closes the modal dialog.
 * @syntax newWindow = openDialog(url, name, features, arg1, arg2, ...)
 * @param {String} url The URL to be loaded in the newly opened window.
 * @param {String} name The window name (optional). See window.open description for detailed information.
 * @param {String} features See window.open description for description.
 * @param {Object} arg1,arg2,... The arguments to be passed to the new window (optional).
 * @returns {Window} The opened window
 * @static
 */
window.openDialog = function(url, name, features, arg1, arg2) {};

/**
 * Returns the toolbar object, whose visibility can be toggled in the window.
 * @returns {Object} 
 * @static
 */
window.toolbar;

/**
 * Returns the menubar object, whose visibility can be checked.
 * @returns {Object} 
 * @static
 */
window.menubar;

/**
 * Closes the current window, or a referenced window.
 * @syntax window.close()
 * @returns {undefined} 
 * @static
 */
window.close = function() {};

/**
 * An event handler property for hash change events on the window; called when the part of the URL after the hash mark ("#") changes.
 * @returns {Function} 
 * @static
 */
window.onhashchange;

/**
 * Returns the locationbar object, whose visibility can be checked.
 * @returns {Object} 
 * @static
 */
window.locationbar;

/**
 * An event handler property for blur events on the window.
 * @returns {Function} 
 * @static
 */
window.onblur;

/**
 * Decodes a string of data which has been encoded using base-64 encoding. For use with Unicode or UTF-8 strings, see this note at window.btoa.
 * @syntax var decodedData = window.atob(encodedData);
 * @param {String} encodedData 
 * @returns {String} 
 * @static
 */
window.atob = function(encodedData) {};

/**
 * Dynamically resizes window.
 * @syntax window.resizeTo(iWidth, iHeight)
 * @param {Number} iWidth iWidth is an integer representing the new outerWidth in pixels (including scroll bars, title bars, etc)
 * @param {Number} iHeight iHeight is an integer value representing the new outerHeight in pixels (including scroll bars, title bars, etc)
 * @returns {undefined} 
 * @static
 */
window.resizeTo = function(iWidth, iHeight) {};

/**
 * Gets/sets the status bar text for the given window.
 * @returns {String} 
 * @static
 */
window.defaultStatus;

/**
 * Scrolls the document by the given number of lines. 
 * @syntax window.scrollByLines(lines)
 * @param {Number} lines Lines is the number of lines to scroll the document by. Lines may be a positive or negative integer.
 * @returns {undefined} 
 * @static
 */
window.scrollByLines = function(lines) {};

/**
 * Returns a new MediaQueryList object representing the parsed results of the specified media query string.
 * @syntax mql = window.matchMedia(mediaQueryString)
 * @param {String} mediaQueryString mediaQueryString is a string representing the media query for which to return a new MediaQueryList object
 * @returns {MediaQueryList} 
 * @static
 */
window.matchMedia = function(mediaQueryString) {};

/**
 * Returns the scrollbars object, whose visibility can be toggled in the window.
 * @returns {Object} 
 * @static
 */
window.scrollbars;

/**
 * Scrolls the window to a particular place in the document.
 * @syntax window.scroll(x-coord, y-coord)
 * @param {Number} x-coord x-coord is the pixel along the horizontal axis of the document that you want displayed in the upper left
 * @param {Number} y-coord y-coord is the pixel along the vertical axis of the document that you want displayed in the upper left
 * @returns {undefined} 
 * @static
 */
window.scroll = function(x-coord, y-coord) {};

/**
 * Sets the text in the status bar at the bottom of the browser or returns the previously set text. This property does not work in default configuration of Firefox and some other browsers: setting window.status has no effect on the text displayed in the status bar. To allow scripts change the the status bar text, the user must set the dom.disable_window_status_change preference to false in the about:config screen.
 * @returns {String} 
 * @static
 */
window.status;

/**
 * An event handler property for mouseout events on the window.
 * @returns {Function} 
 * @static
 */
window.onmouseout;

/**
 * An event handler property for keyup events on the window.
 * @returns {Function} 
 * @static
 */
window.onkeyup;

/**
 * An event handler property for focus events on the window.
 * @returns {Function} 
 * @static
 */
window.onfocus;

/**
 * An event handler property for abort events on the window.
 * @returns {Function} 
 * @static
 */
window.onabort;

/**
 * An event handler property for reset events on the window.
 * @returns {Function} 
 * @static
 */
window.onreset;

/**
 * The console object provides access to the browser's debugging console. The specifics of how it works vary from browser to browser, but there is a de facto set of features that are typically provided.
 * @returns {console} 
 * @static
 */
window.console;

/**
 * An event handler property for window selection.
 * @returns {Function} 
 * @static
 */
window.onselect;

/**
 * Clears the delay set by window.setTimeout().
 * @syntax window.clearTimeout(timeoutID)
 * @param {Number} timeoutID timeoutID is the ID of the timeout you wish to clear, as returned by window.setTimeout().
 * @returns {undefined} 
 * @static
 */
window.clearTimeout = function(timeoutID) {};

/**
 * This method stops window loading.
 * @syntax window.stop()
 * @returns {undefined} 
 * @static
 */
window.stop = function() {};

/**
 * Prints messages to the (native) console.
 * @syntax dump(message);
 * @param {String} message message is the string message to log.
 * @returns {undefined} 
 * @static
 */
window.dump = function(message) {};

/**
 * Updates the state of commands of the current chrome window (UI).
 * @syntax window.updateCommands("sCommandName")
 * @param {String} sCommandName sCommandName is a particular string which describes what kind of update event this is (e.g. whether we are in bold right now)
 * @returns {undefined} 
 * @static
 */
window.updateCommands = function("sCommandName") {};

/**
 * Shifts focus away from the window. 
 * @syntax window.blur()
 * @returns {undefined} 
 * @static
 */
window.blur = function() {};

/**
 * Sizes the window according to its content. The DOM content should be loaded when this function is called, for example after the DOMContentLoaded event.
 * @syntax window.sizeToContent()
 * @returns {undefined} 
 * @static
 */
window.sizeToContent = function() {};

/**
 * An event handler property for errors raised on the window.
 * @returns {Function} 
 * @static
 */
window.onerror;

/**
 * Used for creating a Web worker
 * @syntax worker = new window.Worker(uri)
 * @param {String} url The URI passed as parameter of the Worker constructor must obey the same-origin policy.
 * @returns {Worker} 
 * @static
 */
window.Worker = function(uri) {};

/**
 * Provides a hosting area for performance related attributes.
 * @returns {Object} 
 * @static
 */
window.performance;

/**
 * Property dialogArguments returns parameters of method showModalDialog().
 * @returns {Object} 
 * @static
 */
window.dialogArguments;

/**
 * An event handler property for mouseup events on the window.
 * @returns {Function} 
 * @static
 */
window.onmouseup;

/**
 * An event handler property for window resizing.
 * @returns {Function} 
 * @static
 */
window.onresize;

/**
 * Cancels repeated action which was set up using setInterval().
 * @syntax window.clearInterval(intervalID)
 * @param {Number} intervalID intervalID is the identifier of the repeated action you want to cancel. This ID is returned from setInterval().
 * @returns {undefined} 
 * @static
 */
window.clearInterval = function(intervalID) {};

/**
 * Resizes the current window by a certain amount.
 * @syntax window.resizeBy(xDelta, yDelta)
 * @param {Number} xDelta xDelta is the number of pixels to grow the window horizontally
 * @param {Number} yDelta yDelta is the number of pixels to grow the window vertically
 * @returns {undefined} 
 * @static
 */
window.resizeBy = function(xDelta, yDelta) {};

/**
 * Decodes a value that has been encoded in hexadecimal (e.g., a cookie).
 * @syntax regular = window.unescape(escaped)
 * @param {String} escaped escaped is the encoded string
 * @returns {String} Regular is the decoded string.
 * @static
 */
window.unescape = function(escaped) {};

/**
 * Moves the current window by a specified amount.
 * @syntax window.moveBy(deltaX, deltaY)
 * @param {Number} deltaX deltaX is the amount of pixels to move the window horizontally
 * @param {Number} deltaY deltaY is the amount of pixels to move the window vertically
 * @returns {undefined} 
 * @static
 */
window.moveBy = function(deltaX, deltaY) {};

/**
 * Gets a global object (sessionStorage) that maintains a storage area that's available for the duration of the page session. A page session lasts for as long as the browser is open and survives over page reloads and restores. Opening a page in a new tab or window will cause a new session to be initiated.
 * @returns {Storage} 
 * @static
 */
window.sessionStorage;

/**
 * Finds a string in a window.
 * @syntax window.find(aString, aCaseSensitive, aBackwards, aWrapAround, aWholeWord, aSearchInFrames, aShowDialog);
 * @param {String} aString The text string for which to search.
 * @param {Boolean} aCaseSensitive If true, specifies a case-sensitive search.
 * @param {Boolean} aBackwards If true, specifies a backward search.
 * @param {Boolean} aWrapAround If true, specifies a wrap around search.
 * @param {Boolean} aWholeWord If true, specifies a whole word search.
 * @param {Boolean} aSearchInFrames If true, specifies a search in frames.
 * @param {Boolean} aShowDialog If true, specifies a show Dialog.
 * @returns {Boolean} 
 * @static
 */
window.find = function(aString, aCaseSensitive, aBackwards, aWrapAround, aWholeWord, aSearchInFrames, aShowDialog) {};

/**
 * Calls a function repeatedly, with a fixed time delay between each call to that function.
 * @syntax var intervalID = window.setInterval(func, delay[, param1, param2, ...]);<br>var intervalID = window.setInterval(code, delay);
 * @param {Function} func func is the function you want to be called repeatedly
 * @param {String} code code in the alternate syntax, is a string of code you want to be executed repeatedly. (Using this syntax is not recommended for the same reasons as using eval())
 * @param {Number} delay delay is the number of milliseconds (thousandths of a second) that the setInterval() function should wait before each call to func. As with setTimeout, there is a minimum delay enforced
 * @param {Object} param1,param2,... All parameters will be passed directly to your function.
 * @returns {Number} intervalID is a unique interval ID you can pass to clearInterval()
 * @static
 */
window.setInterval = function(func, delay) {};

/**
 * Moves the window to the specified coordinates.
 * @syntax window.moveTo(x, y)
 * @param {Number} x x is the horizontal coordinate to be moved to
 * @param {Number} y y is the vertical coordinate to be moved to
 * @returns {undefined} 
 * @static
 */
window.moveTo = function(x, y) {};

/**
 * Scrolls the document in the window by the given amount.
 * @syntax window.scrollBy(X, Y);
 * @param {Number} X X is the offset in pixels to scroll horizontally
 * @param {Number} Y Y is the offset in pixels to scroll vertically
 * @returns {undefined} 
 * @static
 */
window.scrollBy = function(X, Y) {};

/**
 * An event handler property for mousemove events on the window.
 * @returns {Function} 
 * @static
 */
window.onmousemove;

/**
 * An event handler property for right-click events on the window.
 * @returns {Function} 
 * @static
 */
window.oncontextmenu;

/**
 * Scrolls to a particular set of coordinates in the document. 
 * @syntax window.scrollTo(x-coord, y-coord)
 * @param {Number} x-coord x-coord is the pixel along the horizontal axis of the document that you want displayed in the upper left
 * @param {Number} y-coord y-coord is the pixel along the vertical axis of the document that you want displayed in the upper left
 * @returns {undefined} 
 * @static
 */
window.scrollTo = function(x-coord, y-coord) {};

/**
 * getComputedStyle() gives the final used values of all the CSS properties of an element.
 * @syntax var style = window.getComputedStyle(element[, pseudoElt]);
 * @param {Element} element The Element for which to get the computed style.
 * @param {String} pseudoElt A string specifying the pseudo-element to match. Must be null (or not specified) for regular elements.
 * @returns {CSSStyleDeclaration} 
 * @static
 */
window.getComputedStyle = function(element) {};

/**
 * An event handler property for change events on the window.
 * @returns {Function} 
 * @static
 */
window.onchange;

/**
 * Opens the Print Dialog to print the current document.
 * @syntax window.print()
 * @returns {undefined} 
 * @static
 */
window.print = function() {};

/**
 * An event handler property for mouseover events on the window.
 * @returns {Function} 
 * @static
 */
window.onmouseover;

/**
 * window.postMessage, when called, causes a MessageEvent to be dispatched at the target window when any pending script that must be executed completes (e.g. remaining event handlers if window.postMessage is called from an event handler, previously-set pending timeouts, etc.). The MessageEvent has the type message, a data property which is set to the value of the first argument provided to window.postMessage, an origin property corresponding to the origin of the main document in the window calling window.postMessage at the time window.postMessage was called, and a source property which is the window from which window.postMessage is called. (Other standard properties of events are present with their expected values.)
 * @syntax otherWindow.postMessage(message, targetOrigin);
 * @param {String} message Data to be sent to the other window.
 * @param {String} targetOrigin Specifies what the origin of otherWindow must be for the event to be dispatched, either as the literal string "*" (indicating no preference) or as a URI. If at the time the event is scheduled to be dispatched the scheme, hostname, or port of otherWindow's document does not match that provided in targetOrigin, the event will not be dispatched; only if all three match will the event be dispatched. This mechanism provides control over where messages are sent; for example, if postMessage were used to transmit a password, it would be absolutely critical that this argument be a URI whose origin is the same as the intended receiver of the message containing the password, to prevent interception of the password by a malicious third party. Always provide a specific targetOrigin, not *, if you know where the other window's document should be located. Failing to provide a specific target discloses the data you send to any interested malicious site.
 * @returns {undefined} 
 * @static
 */
window.postMessage = function(message, targetOrigin) {};

/**
 * Returns a reference to the application cache object for the window.
 * @returns {Object} 
 * @static
 */
window.applicationCache;

/**
 * Returns the statusbar object, whose visibility can be checked.
 * @returns {Object} 
 * @static
 */
window.statusbar;

/**
 * Returns a reference to the navigator object, which can be queried for information about the application running the script.
 * @returns {navigator} 
 * @static
 */
window.navigator;

/**
 * An event handler property for window loading.
 * @returns {Function} 
 * @static
 */
window.onload;

/**
 * An event handler property for click events on the window.
 * @returns {Function} 
 * @static
 */
window.onclick;

/**
 * Represents the window prototype object.
 * @syntax window.prototype
 * @static
 */
window.prototype = new Window();

